@@ -20,29 +20,77 @@ struct Cli {
     /// E.g. `cargo-temp anyhow==1.0.13`
     #[clap(parse(from_str = parse_dependency))]
     dependencies: Vec<(String, Option<String>)>,
+
     /// Name of the temporary crate.
     #[clap(long = "name")]
     project_name: Option<String>,
+
+    /// Create a library instead of a binary.
+    #[clap(long)]
+    lib: bool,
 }
 
 #[derive(Serialize, Deserialize)]
 struct Config {
     temporary_project_dir: String,
     cargo_target_dir: Option<String>,
+    editor: Option<String>,
+    editor_args: Option<Vec<String>>,
 }
 
-impl Default for Config {
-    fn default() -> Self {
+impl Config {
+    pub fn new() -> Result<Self> {
+        #[cfg(unix)]
+        let cache_dir = {
+            let cache_dir = xdg::BaseDirectories::with_prefix(env!("CARGO_PKG_NAME"))
+                .context("Could not find HOME directory")?;
+
+            cache_dir.get_cache_home()
+        };
+        #[cfg(windows)]
         let cache_dir = dirs::cache_dir()
-            .expect("Could not get cache directory")
+            .context("Could not get cache directory")?
             .join(env!("CARGO_PKG_NAME"));
-        Config {
+
+        Ok(Self {
             temporary_project_dir: cache_dir
                 .to_str()
-                .expect("Could not convert cache path into str")
+                .context("Could not convert cache path into str")?
                 .to_string(),
             cargo_target_dir: None,
-        }
+            editor: None,
+            editor_args: None,
+        })
+    }
+
+    pub fn get_or_create() -> Result<Self> {
+        #[cfg(unix)]
+        let config_file_path = {
+            let config_dir = xdg::BaseDirectories::with_prefix("cargo-temp")?;
+            config_dir.place_config_file("config.toml")?
+        };
+        #[cfg(windows)]
+        let config_file_path = {
+            let config_dir = dirs::config_dir()
+                .context("Could not get config directory")?
+                .join(env!("CARGO_PKG_NAME"));
+            let _ = fs::create_dir_all(&config_dir);
+
+            config_dir.join("config.toml")
+        };
+
+        let config: Self = match fs::read(&config_file_path) {
+            Ok(file) => toml::de::from_slice(&file)?,
+            Err(_) => {
+                let config = Self::new()?;
+                fs::write(&config_file_path, toml::ser::to_string(&config)?)?;
+                println!("Config file created at: {}", config_file_path.display());
+
+                config
+            }
+        };
+
+        Ok(config)
     }
 }
 
@@ -52,22 +100,7 @@ fn main() -> Result<()> {
     args.next_if(|x| x.as_str() == "temp");
     let cli = Cli::parse_from(command.into_iter().chain(args));
 
-    let config_dir = dirs::config_dir()
-        .context("Could not get config directory")?
-        .join(env!("CARGO_PKG_NAME"));
-    let _ = fs::create_dir_all(&config_dir);
-
-    let config_file_path = config_dir.join("config.toml");
-
-    let config: Config = match fs::read(&config_file_path) {
-        Ok(file) => toml::de::from_slice(&file)?,
-        Err(_) => {
-            let config = Config::default();
-            fs::write(&config_file_path, toml::ser::to_string(&config)?)?;
-
-            config
-        }
-    };
+    let config = Config::get_or_create()?;
 
     let _ = fs::create_dir(&config.temporary_project_dir);
 
@@ -78,19 +111,22 @@ fn main() -> Result<()> {
         tmp_dir
             .path()
             .file_name()
-            .expect("Cannot retrieve temporary directory name")
-            .to_str()
-            .expect("Cannot convert temporary directory name into str")
+            .unwrap()
+            .to_string_lossy()
             .to_lowercase()
     });
 
-    if !process::Command::new("cargo")
+    let mut command = process::Command::new("cargo");
+
+    command
         .current_dir(&tmp_dir)
-        .args(&["init", "--name", project_name.as_str()])
-        .status()
-        .context("Could not start cargo")?
-        .success()
-    {
+        .args(&["init", "--name", project_name.as_str()]);
+
+    if cli.lib {
+        command.arg("--lib");
+    }
+
+    if !command.status().context("Could not start cargo")?.success() {
         bail!("Cargo command failed");
     };
 
@@ -111,7 +147,16 @@ fn main() -> Result<()> {
     }
     drop(toml);
 
-    let mut shell_process = process::Command::new(get_shell());
+    let mut shell_process = match config.editor {
+        None => process::Command::new(get_shell()),
+        Some(ref editor) => {
+            let mut ide_process = process::Command::new(editor);
+            ide_process
+                .args(config.editor_args.iter().flatten())
+                .arg(tmp_dir.path());
+            ide_process
+        }
+    };
 
     if env::var("CARGO_TARGET_DIR").is_err() {
         if let Some(path) = config.cargo_target_dir {
@@ -124,6 +169,13 @@ fn main() -> Result<()> {
         .status()
         .context("Cannot start shell")?;
 
+    #[cfg(windows)]
+    if config.editor.is_some() {
+        unsafe {
+            cargo_temp_bindings::Windows::Win32::SystemServices::FreeConsole();
+        }
+    }
+
     if !delete_file.exists() {
         println!("Project preserved at: {}", tmp_dir.into_path().display());
     }
